@@ -83,7 +83,7 @@ class Observer : public QObject, public KCalendarCore::Calendar::CalendarObserve
 {
     Q_OBJECT
 public:
-    Observer(Akonadi::CollectionCalendar &calendar)
+    explicit Observer(Akonadi::CollectionCalendar &calendar)
         : mCalendar(calendar)
     {
         mCalendar.registerObserver(this);
@@ -99,9 +99,11 @@ public:
     QSignalSpy incidenceRemovedSpy{this, &Observer::incidenceRemoved};
 
 Q_SIGNALS:
+    // NOLINTBEGIN(readability-inconsistent-declaration-parameter-name)
     void incidenceAdded(const Akonadi::Item &item);
     void incidenceChanged(const Akonadi::Item &item);
     void incidenceRemoved(const Akonadi::Item &item);
+    // NOLINTEND(readability-inconsistent-declaration-parameter-name)
 
 private:
     void calendarIncidenceAdded(const KCalendarCore::Incidence::Ptr &incidence) override
@@ -133,7 +135,8 @@ Akonadi::Collection findResourceCollection(const QString &resource)
         qWarning() << "Failed to fetch collection tree";
         return {};
     }
-    for (const auto &col : fetch->collections()) {
+    const auto collectionList = fetch->collections();
+    for (const auto &col : collectionList) {
         if (col.resource() == resource) {
             return col;
         }
@@ -240,7 +243,7 @@ void CollectionCalendarTest::testPopulateFromReadyETM()
     Akonadi::EntityTreeModel etm(monitor.get());
     QVERIFY(waitForEtmToPopulate(&etm));
 
-    Akonadi::CollectionCalendar calendar(&etm, testCollection);
+    Akonadi::CollectionCalendar const calendar(&etm, testCollection);
 
     // Should populate right away
     QCOMPARE(calendar.incidences().size(), 10);
@@ -250,7 +253,7 @@ void CollectionCalendarTest::testPopulateWhenETMLoads()
 {
     auto monitor = createMonitor();
     Akonadi::EntityTreeModel etm(monitor.get());
-    Akonadi::CollectionCalendar calendar(&etm, testCollection);
+    Akonadi::CollectionCalendar const calendar(&etm, testCollection);
     QVERIFY(!etm.isFullyPopulated());
     QVERIFY(!etm.isCollectionPopulated(testCollection.id()));
     QVERIFY(calendar.incidences().empty());
@@ -271,7 +274,7 @@ void CollectionCalendarTest::testItemAdded()
 
     QCOMPARE(calendar.incidences().size(), 10);
 
-    EphemeralItem item = createIncidence(testCollection, QStringLiteral("New Test Item"));
+    EphemeralItem const item = createIncidence(testCollection, QStringLiteral("New Test Item"));
     QVERIFY(observer.incidenceAddedSpy.wait());
 
     const auto newItem = std::as_const(observer.incidenceAddedSpy)[0][0].value<Akonadi::Item>();
@@ -330,7 +333,7 @@ void CollectionCalendarTest::testItemChanged()
         QVERIFY(observer.incidenceAddedSpy.wait());
         QCOMPARE(calendar.incidences().size(), 11);
 
-        KCalendarCore::Event::Ptr copy(item->payload<KCalendarCore::Event::Ptr>()->clone());
+        KCalendarCore::Event::Ptr const copy(item->payload<KCalendarCore::Event::Ptr>()->clone());
         copy->setSummary(QStringLiteral("Changed"));
         Akonadi::Item newItem = *item;
         newItem.setPayload(copy);
@@ -356,7 +359,7 @@ void CollectionCalendarTest::testUnrelatedItemIsNotSeen()
     QSignalSpy etmRemovedSpy(&etm, &Akonadi::EntityTreeModel::rowsRemoved);
 
     Akonadi::CollectionCalendar calendar(&etm, testCollection);
-    Observer observer(calendar);
+    Observer const observer(calendar);
 
     {
         // Create new incidence in the other collection
