@@ -32,7 +32,7 @@ namespace Akonadi
 class TodoModelPrivate
 {
 public:
-    TodoModelPrivate(TodoModel *qq);
+    explicit TodoModelPrivate(TodoModel *qq);
 
     Akonadi::EntityTreeModel *etm()
     {
@@ -132,8 +132,6 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
     Q_ASSERT(sourceIndex.isValid());
     const auto item = sourceIndex.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
     if (!item.isValid()) {
-        qCWarning(AKONADICALENDAR_LOG) << "Invalid index: " << sourceIndex;
-        // Q_ASSERT( false );
         return {};
     }
     const KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(item);
@@ -212,13 +210,15 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
         case CompletedDateColumn:
             return todo->hasCompletedDate() ? QLocale().toString(todo->completed().toLocalTime().date(), QLocale::ShortFormat) : QVariant(QString());
         case CategoriesColumn: {
-            QString categories = todo->categories().join(i18nc("delimiter for joining category/tag names", ","));
+            QString const categories = todo->categories().join(i18nc("delimiter for joining category/tag names", ","));
             return QVariant(categories);
         }
         case DescriptionColumn:
             return QVariant(todo->description());
         case CalendarColumn:
             return QVariant(Akonadi::CalendarUtils::displayName(d->etm(), item.parentCollection()));
+        default:
+            break;
         }
         return {};
     }
@@ -245,6 +245,8 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
             return QVariant(todo->description());
         case CalendarColumn:
             return QVariant(Akonadi::CalendarUtils::displayName(d->etm(), item.parentCollection()));
+        default:
+            break;
         }
         return {};
     }
@@ -305,6 +307,8 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
         case CategoriesColumn:
         case CalendarColumn:
             return {Qt::AlignHCenter | Qt::AlignVCenter};
+        default:
+            break;
         }
         return {Qt::AlignLeft | Qt::AlignVCenter};
     }
@@ -353,7 +357,7 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
 
     const auto parentCol = Akonadi::EntityTreeModel::updatedCollection(d->etm(), item.parentCollection());
     if (parentCol.rights() & Akonadi::Collection::CanChangeItem) {
-        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
+        KCalendarCore::Todo::Ptr const oldTodo(todo->clone());
         if (role == Qt::CheckStateRole && index.column() == 0) {
             const bool checked = static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked;
             if (checked) {
@@ -394,6 +398,8 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
             case DescriptionColumn:
                 todo->setDescription(value.toString());
                 break;
+            default:
+                break;
             }
         }
 
@@ -477,6 +483,8 @@ QVariant TodoModel::headerData(int column, Qt::Orientation orientation, int role
             return QVariant(i18n("Description"));
         case CalendarColumn:
             return QVariant(i18n("Calendar"));
+        default:
+            break;
         }
     }
 
@@ -491,6 +499,8 @@ QVariant TodoModel::headerData(int column, Qt::Orientation orientation, int role
         case CategoriesColumn:
         case CalendarColumn:
             return {Qt::AlignHCenter};
+        default:
+            break;
         }
         return {};
     }
@@ -543,14 +553,14 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
     if (d->m_changer && (KCalUtils::ICalDrag::canDecode(data) || KCalUtils::VCalDrag::canDecode(data))) {
         // DndFactory only needs a valid calendar for drag event, not for drop event.
         KCalUtils::DndFactory dndFactory(KCalendarCore::Calendar::Ptr{});
-        KCalendarCore::Todo::Ptr t = dndFactory.createDropTodo(data);
-        KCalendarCore::Event::Ptr e = dndFactory.createDropEvent(data);
+        KCalendarCore::Todo::Ptr const t = dndFactory.createDropTodo(data);
+        KCalendarCore::Event::Ptr const e = dndFactory.createDropEvent(data);
 
         if (t) {
             // we don't want to change the created todo, but the one which is already
             // stored in our calendar / tree
             const Akonadi::Item item = d->findItemByUid(t->uid(), QModelIndex());
-            KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(item);
+            KCalendarCore::Todo::Ptr const todo = Akonadi::CalendarUtils::todo(item);
             KCalendarCore::Todo::Ptr destTodo;
             if (parent.isValid()) {
                 const auto parentItem = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
@@ -560,11 +570,11 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
 
                 auto tmpParent = parent;
                 while (tmpParent.isValid()) {
-                    const auto parentItem = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
-                    if (!parentItem.isValid()) {
+                    const auto tmpItem = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+                    if (!tmpItem.isValid()) {
                         break;
                     }
-                    const auto parentTodo = Akonadi::CalendarUtils::todo(parentItem);
+                    const auto parentTodo = Akonadi::CalendarUtils::todo(tmpItem);
                     if (!parentTodo) {
                         break;
                     }
@@ -579,7 +589,7 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
             }
 
             if (!destTodo || !destTodo->hasRecurrenceId()) {
-                KCalendarCore::Todo::Ptr oldTodo = KCalendarCore::Todo::Ptr(todo->clone());
+                KCalendarCore::Todo::Ptr const oldTodo = KCalendarCore::Todo::Ptr(todo->clone());
                 // destTodo is empty when we drag a to-do out of a relationship
                 todo->setRelatedTo(destTodo ? destTodo->uid() : QString());
                 d->m_changer->modifyIncidence(item, oldTodo);
@@ -600,17 +610,17 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
             }
 
             const auto parentItem = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
-            KCalendarCore::Todo::Ptr destTodo = Akonadi::CalendarUtils::todo(parentItem);
+            KCalendarCore::Todo::Ptr const destTodo = Akonadi::CalendarUtils::todo(parentItem);
 
             if (data->hasText()) {
-                QString text = data->text();
+                QString const text = data->text();
 
-                KCalendarCore::Todo::Ptr oldTodo = KCalendarCore::Todo::Ptr(destTodo->clone());
+                KCalendarCore::Todo::Ptr const oldTodo = KCalendarCore::Todo::Ptr(destTodo->clone());
 
                 if (text.startsWith("file:"_L1)) {
                     destTodo->addAttachment(KCalendarCore::Attachment(text));
                 } else {
-                    QStringList emails = KEmailAddress::splitAddressList(text);
+                    QStringList const emails = KEmailAddress::splitAddressList(text);
                     for (QStringList::ConstIterator it = emails.constBegin(); it != emails.constEnd(); ++it) {
                         QString name;
                         QString email;
@@ -662,6 +672,8 @@ Qt::ItemFlags TodoModel::flags(const QModelIndex &index) const
                 ret |= Qt::ItemIsEditable;
             }
             break;
+        default:
+            break;
         }
     }
 
